package cn.fw.morax.domain.db.salary;

import cn.fw.common.data.entity.BaseEntity;
import cn.fw.morax.domain.enums.ReportDimensionEnum;
import cn.fw.morax.domain.enums.StarLevelEnum;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * <p>
 * 报表编码维度数据表
 * </p>
 *
 * @author jiangchao
 * @since 2023-04-17
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName(autoResultMap = true)
public class ReportSalaryDim extends BaseEntity<ReportSalaryDim, Long> {

    private static final long serialVersionUID = 1L;

    /**
     * 薪酬报表id
     */
    private Long reportSalaryId;

    /**
     * 维度(用户,门店)
     */
    private ReportDimensionEnum dimension;

    /**
     * 维度id
     */
    private Long referId;

    /**
     * 薪酬池id(用户维度跳转用)
     */
    private Long salaryPoolId;

    /**
     * 用户id
     */
    private Long userId;

    /**
     * 用户名称
     */
    private String userName;

    /**
     * 岗位id
     */
    private Long postId;

    /**
     * 岗位
     */
    private String postName;

    /**
     * 门店id
     */
    private Long shopId;

    /**
     * 门店名称
     */
    private String shopName;

    /**
     * 日期
     */
    private LocalDate dataDate;

    /**
     * 是否纳入薪酬计算
     */
    private Integer inclusion;

    /**
     * 星级;1: A 2:B 3:C 4:D
     */
    private StarLevelEnum starLevel;

    /**
     * 总薪酬  =  actRevenueTotalMoney(总收入合计) - actDeductTotalMoney(总扣除合计)
     */
    private BigDecimal totalReward;

    /**
     * 绩效得分率(N)
     */
    private BigDecimal kpiScoreRatio;

    /**
     * 总收入合计
     */
    private BigDecimal actRevenueTotalMoney;

    /**
     * 总绩效提成
     */
    private BigDecimal actKpiMoney;

    /**
     * 总内部奖励
     */
    private BigDecimal actAwardMoney;

    /**
     * 总福利补贴
     */
    private BigDecimal actSubsidyMoney;

    /**
     * 总试用期工资
     */
    private BigDecimal actProbationMoney;

    /**
     * 总岗位最低补偿
     */
    private BigDecimal actJobCompensateMoney;

    /**
     * 总考评奖励
     */
    private BigDecimal actEvalAwardMoney;

    /**
     * 总扣除合计
     */
    private BigDecimal actDeductTotalMoney;

    /**
     * 总内部罚款扣除
     */
    private BigDecimal actPenaltyMoney;

    /**
     * 总社保扣除
     */
    private BigDecimal actNecessaryMoney;

    /**
     * 总个税扣除
     */
    private BigDecimal actPersonTaxMoney;

    /**
     * 总公积金扣除
     */
    private BigDecimal actAccumulationFundMoney;

}
